@@ -9,8 +9,12 @@ environment = jinja2.Environment(
     loader=jinja2.FileSystemLoader(TEMPLATE_DIR)
     )
 templates = {
+    'base':environment.get_template("base.jinja"),
     'gallery':environment.get_template("gallery.jinja"),
-    'scroll':environment.get_template('scroll.jinja')
+    'gallery_inner':environment.get_template("gallery_inner.jinja"),
+    'scroll':environment.get_template('scroll.jinja'),
+    'scroll_inner':environment.get_template('scroll_inner.jinja'),
+    'trickle_inner':environment.get_template('trickle_inner.jinja')
 }
 
 def mdown(src:str)->str:
